/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem A. Addictive Bubbles                                   */
/*                                                                */
/* Original idea         Georgiy Korneev                          */
/* Problem statement     Georgiy Korneev                          */
/* Test set              Georgiy Korneev                          */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Georgiy Korneev                          */
/******************************************************************/

import java.io.*;
import java.util.*;

public class Tests {
    static final int MAX_SIZE = 10;
    static final int MAX_COLOR = 9;

    int testNo = 0;
    PrintWriter out;
    static PrintWriter descriptions;
    Random random = new Random(345780305324348L);

    void beginTest(String description, Object... args) {
        ++testNo;
        descriptions.format("%02d: %s\n", testNo, String.format(description, args));
        descriptions.flush();
        try {
            out = new PrintWriter(String.format("tests/%02d", testNo));
        } catch (FileNotFoundException e) {
            throw new AssertionError(e);
        }
    }

    void endTest() {
        out.close();
        assert !out.checkError();
        out = null;
    }

    void writeTest(int h, int w, int[] blueprint, String description, Object... args) {
        assert 0 < h && h <= MAX_SIZE;
        assert 0 < w && w <= MAX_SIZE;
        assert 0 < blueprint.length && blueprint.length <= MAX_COLOR;
        beginTest(description, args);
        out.println(h + " " + w + " " + blueprint.length);
        int total = 0;
        for (int i : blueprint) {
            if (total != 0) out.print(" ");
            out.print(i);
            assert i > 0;
            total += i;
        }
        out.println();
        assert total == w * h;
        endTest();
    }

    public void testRandom(int h, int w, int c) {
        int remaining = h * w;
        c = Math.min(c, h * w);
        int[] blueprint = new int[c];
        for (int i = 0; i < c - 1; i++) {
            blueprint[i] = random.nextInt(Math.min(remaining / (c - i) * 2, remaining - (c - i) + 1)) + 1;
            remaining -= blueprint[i];
        }
        blueprint[c - 1] = remaining;
        writeTest(h, w, blueprint, "Random %d x %d x %d", h, w, c);
    }

    void shuffle(int[] blueprint) {
        for (int i = 0; i < blueprint.length; i++) {
            int j = random.nextInt(i + 1);
            int t = blueprint[i];
            blueprint[i] = blueprint[j];
            blueprint[j] = t;
        }
    }

    public void testBigRandom(int h, int w, int c) {
        int remaining = h * w;
        c = Math.min(c, h * w);
        int[] blueprint = new int[c];
        for (int i = 0; i < c - 1; i++) {
            blueprint[i] = random.nextInt(remaining - (c - i) + 1) + 1;
            remaining -= blueprint[i];
        }
        blueprint[c - 1] = remaining;
        shuffle(blueprint);

        writeTest(h, w, blueprint, "Big random %d x %d x %d", h, w, c);
    }

    public void testSmallRandom(int h, int w, int c) {
        int remaining = h * w;
        c = Math.min(c, h * w);
        int[] blueprint = new int[c];
        for (int i = 0; i < c - 1; i++) {
            blueprint[i] = random.nextInt(Math.min(w - 1, remaining - (c - i) + 1)) + 1;
            remaining -= blueprint[i];
        }
        blueprint[c - 1] = remaining;
        shuffle(blueprint);

        writeTest(h, w, blueprint, "Small random %d x %d x %d", h, w, c);
    }

    public void run() throws IOException {
        writeTest(3, 5, new int[]{4, 4, 7}, "Sample");
        writeTest(1, 1, new int[]{1}, "1 x 1 x 1");
        writeTest(1, 2, new int[]{2}, "1 x 2 x 1");
        writeTest(1, 2, new int[]{1, 1}, "1 x 2 x 1");
        writeTest(2, 1, new int[]{2}, "2 x 1");
        writeTest(2, 1, new int[]{1, 1}, "2 x 1 x 2");
        writeTest(3, 5, new int[]{3, 4, 2, 2, 4}, "Counter updown");
        writeTest(3, 5, new int[]{4, 2, 2, 4, 3}, "Counter bottomup");

        int[] sizes = {MAX_SIZE / 2, MAX_SIZE};
        int[] colors = {MAX_COLOR - 2, MAX_COLOR};
        for (int h : sizes) {
            for (int w : sizes) {
                for (int c : colors) {
                    testBigRandom(h, w, c);
                    testSmallRandom(h, w, c);
                    testRandom(h, w, c);
                    testRandom(h, w, c);
                }
            }
        }
    }

    public static void main(String[] args) throws IOException {
        new File("tests").mkdir();
        descriptions = new PrintWriter("tests/tests.lst");
        new Tests().run();
        descriptions.close();
    }
}

