/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem C. Caravan Robbers                                     */
/*                                                                */
/* Original idea         Egor Kulikov                             */
/* Problem statement     Egor Kulikov                             */
/* Test set              Egor Kulikov                             */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Petr Mitrichev                           */
/******************************************************************/

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.Arrays;
import java.io.BufferedWriter;
import java.util.InputMismatchException;
import java.util.Comparator;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.io.Writer;
import java.math.BigInteger;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class caravan_petr {
	public static void main(String[] args) {
		InputStream inputStream;
		try {
			inputStream = new FileInputStream("caravan.in");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("caravan.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		Caravan solver = new Caravan();
		solver.solve(1, in, out);
		out.close();
	}
}

class Caravan {
    static class Gang {
        long a;
        long b;
    }

	public void solve(int testNumber, InputReader in, OutputWriter out) {
        int n = in.readInt();
        Gang[] gangs = new Gang[n];
        for (int i = 0; i < n; ++i) {
            gangs[i] = new Gang();
            gangs[i].a = in.readInt();
            gangs[i].b = in.readInt();
        }
        Arrays.sort(gangs, new Comparator<Gang>() {
            @Override
            public int compare(Gang o1, Gang o2) {
                return Long.signum(o1.a - o2.a);
            }
        });
        long denom = (long) 1e11;
        long left = 0;
        long right = (long) 1.1e17;
        while (right - left > 1) {
            long middle = (left + right) / 2;
            long at = 0;
            boolean ok = true;
            for (Gang g : gangs) {
                at = Math.max(at, g.a * denom);
                at += middle;
                if (at > g.b * denom) {
                    ok = false;
                    break;
                }
            }
            if (!ok)
                right = middle;
            else
                left = middle;
        }
        for (long q = 1; q <= n; ++q) {
            long p = BigInteger.valueOf(left).multiply(BigInteger.valueOf(2 * q)).add(BigInteger.valueOf(denom)).divide(BigInteger.valueOf(denom * 2)).longValue();
            double delta = BigInteger.valueOf(p).multiply(BigInteger.valueOf(denom)).subtract(BigInteger.valueOf(left).multiply(BigInteger.valueOf(q))).doubleValue() / q / denom;
            if (Math.abs(delta) < 3e-11) {
                out.printLine(p + "/" + q);
                return;
            }
        }
        throw new RuntimeException();
	}
}

class InputReader {

	private InputStream stream;
	private byte[] buf = new byte[1024];
	private int curChar;
	private int numChars;
	private SpaceCharFilter filter;

	public InputReader(InputStream stream) {
		this.stream = stream;
	}

	public int read() {
		if (numChars == -1)
			throw new InputMismatchException();
		if (curChar >= numChars) {
			curChar = 0;
			try {
				numChars = stream.read(buf);
			} catch (IOException e) {
				throw new InputMismatchException();
			}
			if (numChars <= 0)
				return -1;
		}
		return buf[curChar++];
	}

	public int readInt() {
		int c = read();
		while (isSpaceChar(c))
			c = read();
		int sgn = 1;
		if (c == '-') {
			sgn = -1;
			c = read();
		}
		int res = 0;
		do {
			if (c < '0' || c > '9')
				throw new InputMismatchException();
			res *= 10;
			res += c - '0';
			c = read();
		} while (!isSpaceChar(c));
		return res * sgn;
	}

	public boolean isSpaceChar(int c) {
		if (filter != null)
			return filter.isSpaceChar(c);
		return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
	}

	public interface SpaceCharFilter {
		public boolean isSpaceChar(int ch);
	}
}

class OutputWriter {
	private final PrintWriter writer;

	public OutputWriter(OutputStream outputStream) {
		writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
	}

	public OutputWriter(Writer writer) {
		this.writer = new PrintWriter(writer);
	}

	public void print(Object...objects) {
		for (int i = 0; i < objects.length; i++) {
			if (i != 0)
				writer.print(' ');
			writer.print(objects[i]);
		}
	}

	public void printLine(Object...objects) {
		print(objects);
		writer.println();
	}

	public void close() {
		writer.close();
	}

	}


