/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem D. Disjoint Regular Expressions                        */
/*                                                                */
/* Original idea         Roman Elizarov                           */
/* Problem statement     Andrey Stankevich                        */
/* Test set              Andrey Stankevich                        */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Georgiy Korneev                          */
/******************************************************************/

import java.util.*;
import java.io.*;

public class disjoint_gk {
    static Scanner in;
    static PrintWriter out;

    static class Auto {
        Node begin, end;
        boolean nonEmpty;

        public Auto(Node begin, Node end) {
            this.begin = begin;
            this.end = end;
            this.nonEmpty = nonEmpty;
        }

        public boolean equals(Object o) {
            if (o instanceof Auto) {
                Auto that = (Auto) o;
                return this.begin == that.begin && this.end == that.end && this.nonEmpty == that.nonEmpty;
            }
            return false;
        }

        public int hashCode() {
            return begin.hashCode() * 17 + end.hashCode() + (nonEmpty ? 353453453 : 0);
        }
    }

    static class Node {
        List<Node> eps = new ArrayList<>();
        char nextChar;
        Node next;
        boolean accept;
    }

    char[] line;
    int pos = 0;
    Auto parseAuto(String s) {
        line = (s + "#").toCharArray();
        pos = 0;

        Auto result = parseOr();
        expect('#');
        result.end.accept = true;
        return result;
    }

    Auto parseKleene() {
        Auto auto;
        final char token = nextToken();
        if (token == '(') {
            auto = parseOr();
            expect(')');
        } else {
            assert 'a' <= token && token <= 'z';
            auto = new Auto(new Node(), new Node());
            auto.begin.nextChar = token;
            auto.begin.next = auto.end;
        }
        if (test('*')) {
            auto.end.eps.add(auto.begin);
            auto.end = new Node();
            auto.begin.eps.add(auto.end);
        }
        while (test('*'));
        return auto;
    }

    Auto parseSeq() {
        Auto auto = parseKleene();

        while (getToken() != ')' && getToken() != '|' && getToken() != '#') {
            Auto op = parseKleene();
            auto.end.eps.add(op.begin);
            auto.end = op.end;
        }
        return auto;
    }

    Auto parseOr() {
        Auto auto = new Auto(new Node(), new Node());

        do {
            Auto op = parseSeq();
            auto.begin.eps.add(op.begin);
            op.end.eps.add(auto.end);
        } while (test('|'));
        return auto;
    }

    void expect(char ch) {
        if (nextToken() != ch) {
            throw new AssertionError(String.format("%d: '%c' expected, '%c' found", pos, ch, line[pos - 1]));
        }
    }

    char getToken() {
        return line[pos];
    }

    char nextToken() {
        return line[pos++];
    }

    boolean test(char ch) {
        if (line[pos] == ch) {
            pos++;
            return true;
        }
        return false;
    }

    Map<Auto, Map.Entry<Auto, Character>> prev = new HashMap<>();
    Deque<Auto> queue = new ArrayDeque<>();

    void add(Node n1, Node n2, boolean nonEmpty, Auto a, Character c) {
        Auto auto = new Auto(n1, n2);
        auto.nonEmpty = nonEmpty;
        if (prev.containsKey(auto)) return;
        prev.put(auto, new AbstractMap.SimpleEntry<>(a, c));
        if (c != null) {
            queue.addLast(auto);
        } else {
            queue.addFirst(auto);
        }
    }

    void run() {
        String word = run(in.nextLine(), in.nextLine());
        if (word != null) {
            out.println("Wrong");
            out.println(word);
        } else {
            out.println("Correct");
        }
    }

    String run(String s1, String s2) {
        add(parseAuto(s1).begin, parseAuto(s2).begin, false, null, null);
        while (!queue.isEmpty()) {
            Auto auto = queue.removeFirst();

            Node n1 = auto.begin;
            Node n2 = auto.end;
            if (auto.nonEmpty && n1.accept && n2.accept) {
                StringBuilder sb = new StringBuilder();
                while (auto != null) {
                    Map.Entry<Auto, Character> e = prev.get(auto);
                    if (e.getValue() != null) {
                        sb.append(e.getValue());
                    }
                    auto = e.getKey();
                }
                return sb.reverse().toString();
            }
            if (n1.next != null && n2.next != null && n1.nextChar == n2.nextChar) {
                add(n1.next, n2.next, true, auto, n1.nextChar);
            }
            for (Node c1 : n1.eps) {
                add(c1, n2, auto.nonEmpty, auto, null);
            }
            for (Node c2 : n2.eps) {
                add(n1, c2, auto.nonEmpty, auto, null);
            }
        }
        return null;
    }

    public int solve(String s1, String s2) {
        String word = run(s1, s2);
        return word != null ? word.length() : 0;
    }

    public static void main(String[] args) throws Exception {
        in = new Scanner(new File("disjoint.in"));
        out = new PrintWriter("disjoint.out");

        new disjoint_gk().run();

        in.close();
        out.close();
    }
}

