/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem E. Exact Measurement                                   */
/*                                                                */
/* Original idea         Pavel Mavrin                             */
/* Problem statement     Pavel Mavrin                             */
/* Test set              Pavel Mavrin                             */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;
import java.util.ArrayList;
import java.util.List;
import java.util.PriorityQueue;

/**
 * Solution for NEERC'2012 Problem E: Exact Measurement
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class exact_re {
    private static final int MAX_K = 18;
    private static final int BASE = 10;
    private static final long[] POW = new long[MAX_K + 1];

    static {
        POW[0] = 1;
        for (int i = 1; i <= MAX_K; i++)
            POW[i] = BASE * POW[i - 1];
    }

    private static final long MAX_X = POW[18];
    private static final int MAX_N = 100_000;

    public static void main(String[] args) throws Exception {
        new exact_re().go();
    }

    void go() throws Exception {
        long time = System.currentTimeMillis();
        read();
        solve();
        write();
        System.out.printf("Done in %d ms%n", System.currentTimeMillis() - time);
    }

    long x;
    int n;
    int[] k;
    long[] q;

    void read() throws Exception {
        Scanner in = new Scanner(new File("exact.in"));
        x = in.nextLong();
        n = in.nextInt();
        assert x >= 1 && x <= MAX_X;
        assert n >= 1 && n <= MAX_N;
        in.nextLine();
        k = new int[n];
        q = new long[n];
        for (int i = 0; i < n; i++) {
            k[i] = in.nextInt();
            q[i] = in.nextLong();
            assert k[i] >= 0 && k[i] <= MAX_K;
            assert q[i] >= 1 && q[i] * POW[k[i]] <= MAX_X && q[i] <= POW[MAX_K - k[i]];
            in.nextLine();
        }
        in.close();
    }

    static class Box implements Comparable<Box> {
        int id;
        int k;
        long q;
        long w;

        Box(int id, int k, long q) {
            this.id = id;
            this.k = k;
            this.q = q;
            w = POW[k] * q;
        }

        @Override
        public int compareTo(Box o) {
            return Long.compare(o.w, w);
        }
    }

    @SuppressWarnings("unchecked")
    PriorityQueue<Box>[] b = (PriorityQueue<Box>[]) new PriorityQueue[MAX_K + 2];
    List<Box> used = new ArrayList<>();
    boolean found;

    void solve() {
        for (int i = 0; i <= MAX_K + 1; i++)
            b[i] = new PriorityQueue<>();
        for (int i = 0; i < n; i++)
            b[k[i]].add(new Box(i + 1, k[i], q[i]));
        // get rid of powers from lower to larger
        long taken = 0;
        for (int k = 0; k <= MAX_K; k++) {
            long need = k == MAX_K ? x : x % POW[k + 1];
            // use boxes
            while (taken < need) {
                Box box = b[k].poll();
                if (box == null)
                    return; // cannot find solution
                used.add(box);
                taken += box.w;
            }
            // reuse remaining boxes on next step
            b[k + 1].addAll(b[k]);
        }
        found = true;
    }

    void write() throws Exception {
        PrintWriter out = new PrintWriter("exact.out");
        if (found) {
            out.println(used.size());
            for (int i = 0; i < used.size(); i++) {
                if (i > 0)
                    out.print(' ');
                out.print(used.get(i).id);
            }
            out.println();
        } else
            out.println(-1);
        out.close();
    }

//----------------- just for validation ------------------

    /**
     * Strict scanner to verify 100% correspondence between input files and input file format specification.
     * It is a drop-in replacement for {@link java.util.Scanner} that could be added to a solution source
     * (cut-and-paste) without breaking its ability to work with {@link java.util.Scanner}.
     */
    public class Scanner {
        private final BufferedReader in;
        private String line = "";
        private int pos;
        private int lineNo;

        public Scanner(File source) throws FileNotFoundException {
            in = new BufferedReader(new FileReader(source));
            nextLine();
        }

        public void close() {
            assert line == null : "Extra data at the end of file";
            try {
                in.close();
            } catch (IOException e) {
                throw new AssertionError("Failed to close with " + e);
            }
        }

        public void nextLine() {
            assert line != null : "EOF";
            assert pos == line.length() : "Extra characters on line " + lineNo;
            try {
                line = in.readLine();
            } catch (IOException e) {
                throw new AssertionError("Failed to read line with " + e);
            }
            pos = 0;
            lineNo++;
        }

        public String next() {
            assert line != null : "EOF";
            assert line.length() > 0 : "Empty line " + lineNo;
            if (pos == 0)
                assert line.charAt(0) > ' ' : "Line " + lineNo + " starts with whitespace";
            else {
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) == ' ' : "Wrong whitespace on line " + lineNo;
                pos++;
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) > ' ' : "Line " + lineNo + " has double whitespace";
            }
            StringBuilder sb = new StringBuilder();
            while (pos < line.length() && line.charAt(pos) > ' ')
                sb.append(line.charAt(pos++));
            return sb.toString();
        }

        public int nextInt() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Integer.parseInt(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }

        public long nextLong() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Long.parseLong(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }
    }
}

