/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem F. Folding Snake Cube                                  */
/*                                                                */
/* Original idea         Roman Elizarov                           */
/* Problem statement     Roman Elizarov                           */
/* Test set              Roman Elizarov                           */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Andrey Halyavin                          */
/******************************************************************/

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.util.Arrays;
import java.io.BufferedWriter;
import java.util.InputMismatchException;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.io.Writer;
import java.util.HashSet;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class folding_halyavin {
	public static void main(String[] args) {
		InputStream inputStream;
		try {
			inputStream = new FileInputStream("folding.in");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("folding.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		Folding solver = new Folding();
		solver.solve(1, in, out);
		out.close();
	}
}

class Folding {
    int[] x;
    int[] y;
    boolean[] straight;

    int fromChar(char c) {
        if (c >= 'a' && c <= 'z') {
            return (c - 'a') * 2 + 1;
        }
        return (c - 'A') * 2;
    }

    char toChar(int x) {
        if (x % 2 == 0) {
            return (char) ('A' + (x / 2));
        }
        return (char) ('a' + (x / 2));
    }

    public void fillStraight() {
        straight[0] = true;
        straight[1] = true;
        for (int i = 2; i < 27; i++) {
            if (x[i] - x[i - 1] == x[i - 1] - x[i - 2] && y[i] - y[i - 1] == y[i - 1] - y[i - 2]) {
                straight[i] = true;
            } else {
                straight[i] = false;
            }
        }
    }

    int[] dx = new int[]{1, -1, 0, 0, 0, 0};
    int[] dy = new int[]{0, 0, 1, -1, 0, 0};
    int[] dz = new int[]{0, 0, 0, 0, 1, -1};
    HashSet<Integer>[][] remember = new HashSet[27][6];
    int[][][] solution = new int[3][3][3];

    boolean rec(int x, int y, int z, int dir, int mask, int gl) {
        if (remember[9 * x + 3 * y + z][dir].contains(mask)) {
            return false;
        }
        if (gl == 26) {
            return true;
        }
        if (straight[gl + 1]) {
            int newx = x + dx[dir];
            int newy = y + dy[dir];
            int newz = z + dz[dir];
            if (newx >= 0 && newx < 3 && newy >= 0 && newy < 3 && newz >= 0 && newz < 3 && solution[newx][newy][newz] == -1) {
                solution[newx][newy][newz] = gl + 1;
                if (rec(newx, newy, newz, dir, mask + (1 << (9 * newx + 3 * newy + newz)), gl + 1)) {
                    return true;
                }
                solution[newx][newy][newz] = -1;
            }
        } else {
            for (int newdir = 0; newdir < 6; newdir++) {
                if ((dir ^ newdir) <= 1) {
                    continue;
                }
                int newx = x + dx[newdir];
                int newy = y + dy[newdir];
                int newz = z + dz[newdir];
                if (newx < 0 || newx >= 3 || newy < 0 || newy >= 3 || newz < 0 || newz >= 3) {
                    continue;
                }
                if (solution[newx][newy][newz] != -1) {
                    continue;
                }
                solution[newx][newy][newz] = gl + 1;
                if (rec(newx, newy, newz, newdir, mask + (1 << (9 * newx + 3 * newy + newz)), gl + 1)) {
                    return true;
                }
                solution[newx][newy][newz] = -1;
            }
        }
        remember[9 * x + 3 * y + z][dir].add(mask);
        return false;
    }

    void recAll() {
        solution[0][0][0] = 0;
        if (rec(0, 0, 0, 0, 1, 0)) {
            return;
        }
        solution[0][0][0] = -1;
        solution[0][1][1] = 0;
        if (rec(0, 1, 1, 0, 1 << (4), 0)) {
            return;
        }
        if (rec(0, 1, 1, 2, 1 << (4), 0)) {
            return;
        }
        solution[0][1][1] = -1;
        solution[1][1][1] = 0;
        if (rec(1, 1, 1, 0, 1 << (13), 0)) {
            return;
        }
    }

    public void solve(int testNumber, InputReader in, OutputWriter out) {
        x = new int[27];
        y = new int[27];
        for (int i = 0; i < 15; i++) {
            String s = in.readString();
            for (int j = 0; j < 15; j++) {
                if (s.charAt(j) != '.') {
                    int num = fromChar(s.charAt(j));
                    x[num] = i;
                    y[num] = j;
                }
            }
        }
        straight = new boolean[27];
        fillStraight();
        for (int i = 0; i < 27; i++) {
            for (int j = 0; j < 6; j++) {
                remember[i][j] = new HashSet<Integer>();
            }
        }
        for (int i = 0; i < 3; i++) {
            for (int j = 0; j < 3; j++) {
                Arrays.fill(solution[i][j], -1);
            }
        }
        recAll();
        for (int i = 0; i < 3; i++) {
            for (int j = 0; j < 3; j++) {
                for (int k = 0; k < 3; k++) {
                    out.print(toChar(solution[i][j][k]));
                }
                if (j < 2) out.print(" ");
            }
            out.printLine();
        }
    }
}

class InputReader {

	private InputStream stream;
	private byte[] buf = new byte[1024];
	private int curChar;
	private int numChars;
	private SpaceCharFilter filter;

	public InputReader(InputStream stream) {
		this.stream = stream;
	}

	public int read() {
		if (numChars == -1)
			throw new InputMismatchException();
		if (curChar >= numChars) {
			curChar = 0;
			try {
				numChars = stream.read(buf);
			} catch (IOException e) {
				throw new InputMismatchException();
			}
			if (numChars <= 0)
				return -1;
		}
		return buf[curChar++];
	}

	public String readString() {
		int c = read();
		while (isSpaceChar(c))
			c = read();
		StringBuilder res = new StringBuilder();
		do {
			res.appendCodePoint(c);
			c = read();
		} while (!isSpaceChar(c));
		return res.toString();
	}

	public boolean isSpaceChar(int c) {
		if (filter != null)
			return filter.isSpaceChar(c);
		return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
	}

	public interface SpaceCharFilter {
		public boolean isSpaceChar(int ch);
	}
}

class OutputWriter {
	private final PrintWriter writer;

	public OutputWriter(OutputStream outputStream) {
		writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
	}

	public OutputWriter(Writer writer) {
		this.writer = new PrintWriter(writer);
	}

	public void print(Object...objects) {
		for (int i = 0; i < objects.length; i++) {
			if (i != 0)
				writer.print(' ');
			writer.print(objects[i]);
		}
	}

	public void printLine(Object...objects) {
		print(objects);
		writer.println();
	}

	public void close() {
		writer.close();
	}

	}


