/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem H. Hyperdrome                                          */
/*                                                                */
/* Original idea         Vitaliy Aksenov                          */
/* Problem statement     Vitaliy Aksenov                          */
/* Test set              Vitaliy Aksenov                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;
import java.util.HashMap;

/**
 * Solution for NEERC'2012 Problem H: Hyperdrome
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class hyperdrome_re_hashmap_boxing {
    private static final boolean DEBUG = false;

    public static void main(String[] args) throws Exception {
        new hyperdrome_re_hashmap_boxing().go();
    }

    void go() throws Exception {
        long time = System.currentTimeMillis();
        read();
        solve();
        write();
        System.out.printf("Done in %d ms%n", System.currentTimeMillis() - time);
    }

    int n;
    String s;

    void read() throws Exception {
        Scanner in = new Scanner(new File("hyperdrome.in"));
        n = in.nextInt();
        assert n >= 1 && n <= 300000;
        in.nextLine();
        s = in.next();
        assert s.length() == n;
        for (int i = 0; i < n; i++) {
            char c = s.charAt(i);
            assert c >= 'a' && c <= 'z' || c >= 'A' && c <= 'Z';
        }
        in.nextLine();
        in.close();
    }

    HashMap<Long, Integer> hash;

    long result;

    void solve() {
        hash = new HashMap<>();
        hash.put((long) 0, 1);
        long mask = 0L;
        for (int i = 0; i < n; i++) {
            char c = s.charAt(i);
            int j;
            if (c >= 'a' && c <= 'z')
                j = c - 'a';
            else if (c >= 'A' && c <= 'z')
                j = c - 'A' + 26;
            else
                throw new AssertionError();
            mask ^= 1L << j;
            Integer ccc = hash.get(mask);
            int cc;
            if (ccc != null) {
                cc = ccc;
                result += ccc;
                if (DEBUG && ccc > 0)
                    System.out.println("@" + i + "[" + s.substring(0, i + 1) + "]: even +=" + ccc);
            } else
                cc = 0;
            for (int k = 0; k < 2 * 26; k++) {
                Integer ooo = hash.get(mask ^ (1L << k));
                if (ooo != null) {
                    result += ooo;
                    if (DEBUG && ooo > 0)
                        System.out.println("@" + i + "[" + s.substring(0, i + 1) + "]: odd " + k + " += " + ooo);
                }
            }
            hash.put(mask, cc + 1);
        }
    }

    void write() throws Exception {
        PrintWriter out = new PrintWriter("hyperdrome.out");
        out.println(result);
        out.close();
    }

//----------------- just for validation ------------------

    /**
     * Strict scanner to verify 100% correspondence between input files and input file format specification.
     * It is a drop-in replacement for {@link java.util.Scanner} that could be added to a solution source
     * (cut-and-paste) without breaking its ability to work with {@link java.util.Scanner}.
     */
    public class Scanner {
        private final BufferedReader in;
        private String line = "";
        private int pos;
        private int lineNo;

        public Scanner(File source) throws FileNotFoundException {
            in = new BufferedReader(new FileReader(source));
            nextLine();
        }

        public void close() {
            assert line == null : "Extra data at the end of file";
            try {
                in.close();
            } catch (IOException e) {
                throw new AssertionError("Failed to close with " + e);
            }
        }

        public void nextLine() {
            assert line != null : "EOF";
            assert pos == line.length() : "Extra characters on line " + lineNo;
            try {
                line = in.readLine();
            } catch (IOException e) {
                throw new AssertionError("Failed to read line with " + e);
            }
            pos = 0;
            lineNo++;
        }

        public String next() {
            assert line != null : "EOF";
            assert line.length() > 0 : "Empty line " + lineNo;
            if (pos == 0)
                assert line.charAt(0) > ' ' : "Line " + lineNo + " starts with whitespace";
            else {
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) == ' ' : "Wrong whitespace on line " + lineNo;
                pos++;
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) > ' ' : "Line " + lineNo + " has double whitespace";
            }
            StringBuilder sb = new StringBuilder();
            while (pos < line.length() && line.charAt(pos) > ' ')
                sb.append(line.charAt(pos++));
            return sb.toString();
        }

        public int nextInt() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Integer.parseInt(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }
    }
}

