/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem J. Jumping Around                                      */
/*                                                                */
/* Original idea         Andrey Stankevich                        */
/* Problem statement     Andrey Stankevich                        */
/* Test set              Andrey Stankevich                        */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Roman Elizarov                           */
/******************************************************************/

import java.io.*;
import java.util.ArrayList;
import java.util.List;

/**
 * Solution for NEERC'2012 Problem J: Jumping around
 * This solution checks correctness of the input.
 *
 * @author Roman Elizarov
 */
public class jumping_re {

    public static void main(String[] args) throws Exception {
        new jumping_re().go();
    }

    void go() throws Exception {
        long time = System.currentTimeMillis();
        read();
        solve();
        write();
        System.out.printf("Done in %d ms%n", System.currentTimeMillis() - time);
    }

    static class TC {
        int a;
        int b;
        int c;

        // solution
        int n;
        List<Integer> r;
        int x;
    }

    TC[] tcs;

    void read() throws Exception {
        Scanner in = new Scanner(new File("jumping.in"));
        int t = in.nextInt();
        assert t >= 1 && t <= 20;
        in.nextLine();
        tcs = new TC[t];
        for (int i = 0; i < t; i++) {
            TC tc = tcs[i] = new TC();
            tc.a = in.nextInt();
            tc.b = in.nextInt();
            tc.c = in.nextInt();
            assert inRange(tc.a) && inRange(tc.b) && inRange(tc.c);
            in.nextLine();
        }
        in.close();
    }

    private boolean inRange(int n) {
        return n >= 3 && n <= 5000;
    }

    void solve() {
        for (TC tc : tcs)
            visit(tc);
    }

    private void visit(TC tc) {
        tc.n = tc.a + tc.b + tc.c + 1;
        tc.r = new ArrayList<>(tc.n);
        tc.r.add(0);
        int cc = tc.c / 3;
        switch (tc.c % 3) {
            case 0:
                jumpTo(tc, 3 * cc, 3);  // cc times
                jumpTo(tc, 3 * cc + 1, 1);
                jumpTo(tc, 1, -3); // cc times
                jumpTo(tc, 2, 1);
                jumpTo(tc, 3 * cc + 2, 3); // cc times
                break;
            case 1:
                jumpTo(tc, 3 * cc + 3, 3); // cc + 1 times
                jumpTo(tc, 3 * cc + 1, -2);
                jumpTo(tc, 1, -3); // cc times
                jumpTo(tc, 2, 1);
                jumpTo(tc, 3 * cc + 2, 3); // cc times
                jumpTo(tc, 3 * cc + 4, 2);
                break;
            case 2:
                jumpTo(tc, 3 * cc + 3, 3); // cc + 1 times
                jumpTo(tc, 3 * cc + 2, -1);
                jumpTo(tc, 2, -3); // cc times
                jumpTo(tc, 1, -1);
                jumpTo(tc, 3 * cc + 4, 3); // cc + 1 times
                break;
        }
        jumpTo(tc, tc.x + tc.a - 1, 1); // leave one A ticket
        int bb = tc.b / 2;
        switch (tc.b % 2) {
            case 0:
                jumpTo(tc, tc.x + bb * 2, 2); // bb times
                jumpTo(tc, tc.x + 1, 1);
                jumpTo(tc, tc.x - bb * 2, -2); // bb times
                break;
            case 1:
                jumpTo(tc, tc.x + bb * 2 + 2, 2); // bb + 1 times
                jumpTo(tc, tc.x - 1, -1);
                jumpTo(tc, tc.x - bb * 2, -2); // bb times
                break;
        }
        assert tc.a == 0 && tc.b == 0 && tc.c == 0 && tc.r.size() == tc.n;
    }

    private void jumpTo(TC tc, int to, int step) {
        while (tc.x != to) {
            tc.x += step;
            tc.r.add(tc.x);
            switch (Math.abs(step)) {
                case 1:
                    tc.a--;
                    assert tc.a >= 0;
                    break;
                case 2:
                    tc.b--;
                    assert tc.b >= 0;
                    break;
                case 3:
                    tc.c--;
                    assert tc.c >= 0;
                    break;
                default:
                    throw new AssertionError("wrong step");
            }
        }
    }

    void write() throws Exception {
        PrintWriter out = new PrintWriter("jumping.out");
        for (TC tc : tcs) {
            for (int i = 0; i < tc.r.size(); i++) {
                if (i > 0)
                    out.print(' ');
                out.print((int) tc.r.get(i));
            }
            out.println();
        }
        out.close();
    }


//----------------- just for validation ------------------

    /**
     * Strict scanner to verify 100% correspondence between input files and input file format specification.
     * It is a drop-in replacement for {@link java.util.Scanner} that could be added to a solution source
     * (cut-and-paste) without breaking its ability to work with {@link java.util.Scanner}.
     */
    public class Scanner {
        private final BufferedReader in;
        private String line = "";
        private int pos;
        private int lineNo;

        public Scanner(File source) throws FileNotFoundException {
            in = new BufferedReader(new FileReader(source));
            nextLine();
        }

        public void close() {
            assert line == null : "Extra data at the end of file";
            try {
                in.close();
            } catch (IOException e) {
                throw new AssertionError("Failed to close with " + e);
            }
        }

        public void nextLine() {
            assert line != null : "EOF";
            assert pos == line.length() : "Extra characters on line " + lineNo;
            try {
                line = in.readLine();
            } catch (IOException e) {
                throw new AssertionError("Failed to read line with " + e);
            }
            pos = 0;
            lineNo++;
        }

        public String next() {
            assert line != null : "EOF";
            assert line.length() > 0 : "Empty line " + lineNo;
            if (pos == 0)
                assert line.charAt(0) > ' ' : "Line " + lineNo + " starts with whitespace";
            else {
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) == ' ' : "Wrong whitespace on line " + lineNo;
                pos++;
                assert pos < line.length() : "Line " + lineNo + " is over";
                assert line.charAt(pos) > ' ' : "Line " + lineNo + " has double whitespace";
            }
            StringBuilder sb = new StringBuilder();
            while (pos < line.length() && line.charAt(pos) > ' ')
                sb.append(line.charAt(pos++));
            return sb.toString();
        }

        public int nextInt() {
            String s = next();
            assert s.length() == 1 || s.charAt(0) != '0' : "Extra leading zero in number " + s + " on line " + lineNo;
            assert s.charAt(0) != '+' : "Extra leading '+' in number " + s + " on line " + lineNo;
            try {
                return Integer.parseInt(s);
            } catch (NumberFormatException e) {
                throw new AssertionError("Malformed number " + s + " on line " + lineNo);
            }
        }
    }
}

