/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem L. Labyrinth of the Minotaur                           */
/*                                                                */
/* Original idea         Georgiy Korneev                          */
/* Problem statement     Georgiy Korneev                          */
/* Test set              Georgiy Korneev                          */
/******************************************************************/
/* Tests                                                          */
/*                                                                */
/* Author                Georgiy Korneev                          */
/******************************************************************/

import javax.imageio.ImageIO;
import java.awt.*;
import java.awt.image.BufferedImage;
import java.io.*;
import java.util.Arrays;
import java.util.Random;

public class Tests {
    static final int MAX_N = 1500;

    int testNo = 0;
    PrintWriter out;
    static PrintWriter descriptions;
    static Random random = new Random(3458730583593845324L);

    void beginTest(String description, Object... args) {
        ++testNo;
        System.out.println("Writing test " + testNo + ": " + String.format(description, args));
        descriptions.format("%03d: %s\n", testNo, String.format(description, args));
        descriptions.flush();
        try {
            out = new PrintWriter(String.format("tests/%03d", testNo));
        } catch (FileNotFoundException e) {
            throw new AssertionError(e);
        }
    }

    void endTest() {
        out.close();
        assert !out.checkError();
        out = null;
    }

    private static final String[][] MANUAL = {
            {
                    "......#####",
                    ".#.#...#..#",
                    ".#.#.......",
                    ".......###.",
                    "#####.###..",
                    "#####......",
            },
            {
                    "...",
                    ".#.",
                    "...",
            },
            {
                    ".#.",
                    "...",
                    ".#.",
            },
            {
                    "..",
                    "..",
            },
            {
                    "...",
                    "...",
            },
            {
                    "....",
                    "....",
            },
            {
                    "..",
                    "..",
                    "..",
            },
            {
                    "..",
                    "..",
                    "..",
                    "..",
            },
            {
                    "...",
                    "...",
                    "...",
            },
            {
                    ".....",
                    ".#...",
                    ".....",
                    ".....",
                    ".#...",
            },
            {
                    ".....",
                    ".#..#",
                    ".....",
                    ".....",
                    "....."
            }
    };

    private void manual() throws IOException {
        for (String[] m : MANUAL) {
            int w = m[0].length();
            int h = m.length;
            boolean[][] maze = new boolean[h][w];
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    maze[i][j] = m[i].charAt(j) == '.';
                }
            }
            writeTest(maze, "manual %dx%d", h, w);
        }
    }

    void writeTest(boolean[][] maze, String description, Object... args) {
        beginTest(description, args);

        int h = maze.length;
        int w = maze[0].length;
        out.println(w + " " + h);
        assert maze[0][0];
        assert maze[h - 1][w - 1];

        for (boolean[] row : maze) {
            assert row.length == maze[0].length;
            for (boolean c : row) {
                out.print(c ? '.' : '#');
            }
            out.println();
        }
        endTest();
        assert isSolvable(maze);
    }

    boolean isSolvable(boolean[][] maze) {
        int h = maze.length;
        int w = maze[0].length;
        boolean[] u = new boolean[h * w];
        int[] queue = new int[h * w];
        u[0] = true;
        int head = 0;
        int tail = 1;
        while (head != tail) {
            int c = queue[head++];
            int x = c % w;
            int y = c / w;
            int c4 = y * w + x - 1;
            if (0 <= x - 1 && x - 1 < w && 0 <= y && y < h && maze[y][(x - 1)] && !u[c4]) {
                u[c4] = true;
                queue[tail++] = c4;
            }
            int c3 = y * w + x + 1;
            if (0 <= x + 1 && x + 1 < w && 0 <= y && y < h && maze[y][(x + 1)] && !u[c3]) {
                u[c3] = true;
                queue[tail++] = c3;
            }
            int c2 = (y - 1) * w + x;
            if (0 <= x && x < w && 0 <= y - 1 && y - 1 < h && maze[(y - 1)][x] && !u[c2]) {
                u[c2] = true;
                queue[tail++] = c2;
            }
            int c1 = (y + 1) * w + x;
            if (0 <= x && x < w && 0 <= y + 1 && y + 1 < h && maze[(y + 1)][x] && !u[c1]) {
                u[c1] = true;
                queue[tail++] = c1;
            }
        }
        return u[w * h - 1];
    }

    final static int[] DX = new int[]{1, 0, -1, 0};
    final static int[] DY = new int[]{0, -1, 0, 1};

    boolean nextPermutation(int[] p) {
        int a = p.length - 2;
        while (a >= 0 && p[a] >= p[a + 1]) {
            a--;
        }
        if (a == -1) {
            return false;
        }
        int b = p.length - 1;
        while (p[b] <= p[a]) {
            b--;
        }
        int t = p[a];
        p[a] = p[b];
        p[b] = t;
        for (int i = a + 1, j = p.length - 1; i < j; i++, j--) {
            t = p[i];
            p[i] = p[j];
            p[j] = t;
        }
        return true;
    }

    int[][] shuffled = new int[24][4];
    {
        int[] p = new int[]{0, 1, 2, 3};
        for (int i = 0; i < 24; i++) {
            shuffled[i] = p.clone();
            nextPermutation(p);
        }
    }

    public class IntList {
        boolean[][] v;
        int[] data;
        int size;
        boolean found;

        public IntList(int h, int w) {
            v = new boolean[h][w];
            data = new int[h * w];
        }

        private int removeRandom() {
            int r = random.nextInt(size);
            int c = this.data[r];
            this.data[r] = this.data[--size];
            return c;
        }

        private int removeLast() {
            return this.data[--size];
        }

        private IntList add(int value) {
            data[size] = value;
            size++;
            return this;
        }

        private boolean isEmpty() {
            return size == 0;
        }

        public boolean hasNeighbor(int y, int x, Maze maze) {
            for (int i = 0; i < 4; i++) {
                int ny = y + DY[i];
                int nx = x + DX[i];
                if (maze.inside(ny, nx) && v[ny][nx]) {
                    return true;
                }
            }
            return false;
        }

        public void clear() {
            size = 0;
        }
    }

    class Maze {
        final int h, w;
        String description;
        boolean[][] maze;
        boolean[][] u;

        Maze(int h, int w) {
            this.h = h;
            this.w = w;
            maze = new boolean[h][w];
        }

        Maze prim(int s) {
            IntList active;
            int t = 0;
            do {
                if (++t % 100 == 0) {
                    System.out.format("    prim(%d) %dx%d try %d\n", s, w, h, t);
                }
                u = new boolean[h][w];
                fill(false);

                active = list(0);
                while (!active.isEmpty()) {
                    addNew(active.removeRandom(), s, active);
                }
                fill(h - s, w - s, h, w, true);
            } while (!isSolvable(maze));
            description = String.format("prim(%d) %dx%d", s, h, w);
            return this;
        }

        private void printMaze(int y, int x) {
            printMaze(y, x, maze);
        }

        private void printMaze(int y, int x, boolean[][] maze1) {
            for (int i = 0; i < maze1.length; i++) {
                boolean[] row = maze1[i];
                assert row.length == maze1[0].length;
                for (int j = 0; j < row.length; j++) {
                    boolean b = row[j];
                    System.out.print(i == y && j == x ? '?' : b ? '.' : '#');
                }
                System.out.println();
            }
            System.out.println();
        }

        public Maze dfs(int s) {
            int t = 0;
            do {
                if (++t % 100 == 0) {
                    System.out.format("    dfs(%d) %dx%d try %d\n", s, w, h, t);
                }
                fill(false);
                u = new boolean[h][w];
                fill(0, 0, s, s, true);

                IntList active = list(0);
                while (!active.isEmpty()) {
                    addNew(active.removeLast(), s, active);
                }
            } while (!isSolvable(maze));
            description = String.format("dfs(%d) %dx%d", s, h, w);
            return this;
        }

        Maze primPaths(int s, boolean both) {
            assert w / h <= 25 && h / w <= 25;
            int t = 0;
            while (true) {
                System.out.format("    %s(%d) %dx%d try %d\n", (both ? "two paths" : "single path"), s, w, h, ++t);
                u = new boolean[h][w];
                fill(false);
                IntList[] actives = new IntList[]{list(1), list(w), list((h - s) * w + (w - s) - w), list((h - s) * w + (w - s) - s)};
                boolean found;
                do {
                    found = false;
                    for (IntList active : actives) {
                        found |= !active.isEmpty();
                        while (!active.isEmpty() && !addNew(active.removeRandom(), s, active)) {}
                    }
                } while (found);
                if (both) {
                    if (connect(actives[0], actives[2], s) && connect(actives[1], actives[3], s) || connect(actives[0], actives[3], s) && connect(actives[1], actives[2], s)) {
                        description = String.format("two prim(%d) paths %dx%d", s, h, w);
                        return this;
                    }
                } else {
                    if (random.nextBoolean() ? connect(actives[0], actives[2], s) : connect(actives[1], actives[3], s)) {
                        description = String.format("single prim(%d) path %dx%d", s, h, w);
                        return this;
                    }
                }
            }
        }

        private IntList list(int value) {
            return new IntList(h, w).add(value);
        }

        private boolean connect(IntList active1, IntList active2, int s) {
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    if (
                            active1.hasNeighbor(i, j, this) && active2.hasNeighbor(i + s - 1, j, this) ||
                                    active1.hasNeighbor(i, j, this) && active2.hasNeighbor(i, j + s - 1, this) ||
                                    active1.hasNeighbor(i + s - 1, j, this) && active2.hasNeighbor(i, j, this) ||
                                    active1.hasNeighbor(i, j + s - 1, this) && active2.hasNeighbor(i, j, this)
                            ) {
                        fill(i, j, i + s, j + s, true);
                        return true;
                    }
                }
            }
            return false;
        }

        boolean inside(int y, int x) {
            return 0 <= y && y < maze.length && 0 <= x && x < maze[y].length;
        }

        boolean empty(int y, int x) {
            return inside(y, x) && maze[y][x];
        }

        boolean blocked(int y, int x) {
            return !inside(y, x) || !maze[y][x];
        }

        public void write() {
            Solution solution = solve();
            writeTest(maze, "%s; %s",
                    description, solution.solutions.isEmpty()
                    ? "Impossible"
                    : String.format("%d solutions, (%d, %d, %d)", solution.solutions.size, solution.s, solution.solutions.data[0] % w + 1, solution.solutions.data[0] / w + 1)
            );
            BufferedImage img = new BufferedImage(w, h, BufferedImage.TYPE_INT_RGB);
            Graphics2D g = (Graphics2D) img.getGraphics();
            g.setBackground(Color.BLACK);
            g.setColor(Color.WHITE);
            g.clearRect(0, 0, w, h);
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    if (maze[i][j]) {
                        g.fillRect(j, i, 1, 1);
                    }
                }
            }
            g.setColor(new Color(0, 255, 0, 100));
            for (int i = 0; i < solution.solutions.size; i++) {
                int c = solution.solutions.data[i];
                g.fillRect(c % w, c / w, solution.s, solution.s);
            }
            try {
                ImageIO.write(img, "png", new File(String.format("images/%03d.png", testNo)));
            } catch (IOException e) {
                throw new RuntimeException(e);
            }
        }

        public Maze scale(int scale, double noise) {
            if (scale == 1) {
                return this;
            }
            Maze m = new Maze(maze.length * scale, maze[0].length * scale);
            m.description = String.format("%s, scaled by %d to %dx%d", description, scale, m.h, m.w);
            for (int i = 0; i < m.h; i++) {
                for (int j = 0; j < m.w; j++) {
                    m.maze[i][j] = maze[i / scale][j / scale];
//                    int di = Math.abs(i % scale - scale / 2);
//                    int dj = Math.abs(j % scale - scale / 2);
//                    if ((i / scale != 0 && j  / scale != 0) && (i / scale != h - 1 && j / scale != w - 1)) {
//                        if (!m.maze[i][j] && di != dj && di != scale - dj - 1) {
//                            m.maze[i][j] = (di*di + dj*dj) * 2 > random.nextDouble() * scale * scale;
//                        } else if (m.maze[i][j] && di > scale / 4 && dj > scale / 4) {
//                            m.maze[i][j] = (di*di + dj*dj) * 2 < random.nextDouble() * scale * scale;
//                        }
//                    }
                }
            }
            return m.noise(noise);
        }

        public Maze recursive(int min, boolean fair) {
            int t = 0;
            do {
                System.out.format("    recursive(%d, %b) %dx%d try %d\n", min, fair, w, h, ++t);
                fill(true);
                recursive(min, fair, 0, 0, h, w);
            } while (!isSolvable(maze));
            description = String.format("recursive(%d) %dx%d", min, h, w);
            return this;
        }

        private void fill(boolean value) {
            for (boolean[] row : maze) {
                Arrays.fill(row, value);
            }
        }

        private void recursive(int min, boolean fair, int y1, int x1, int y2, int x2) {
            int dy = y2 - y1;
            int dx = x2 - x1;
            assert min <= dy;
            assert min <= dx;
            if (dy >= random.nextInt(dx + dy) && fair || random.nextBoolean() && !fair) {
                if (dy <= 2 * min || dx == min) return;
                int y = y1 + min + random.nextInt(dy - 2 * min);
                int wx = x1 + random.nextInt(dx - min + 1);
                for (int x = x1; x < x2; x++) {
                    maze[y][x] = wx <= x && x < wx + min;
                }
                recursive(min, fair, y1, x1, y, x2);
                recursive(min, fair, y + 1, x1, y2, x2);
            } else {
                if (dx <= 2 * min || dy == min) return;
                int x = x1 + min + random.nextInt(dx - 2 * min);
                int wy = y1 + random.nextInt(dy - min + 1);
                for (int y = y1; y < y2; y++) {
                    maze[y][x] = wy <= y && y < wy + min;
                }
                recursive(min, fair, y1, x1, y2, x);
                recursive(min, fair, y1, x + 1, y2, x2);
            }
        }

        public Maze or(Maze that) {
            description += " or (" + that.description + ")";
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    maze[i][j] |= that.maze[i][j];
                }
            }
            return this;
        }

        public Maze impossible(int s) {
            for (int i = 0; i < s; i++) {
                for (int j = 0; j < s; j++) {
                    maze[i][j] = true;
                    maze[h - 1 - i][w - 1 - j] = true;
                }
            }
            description += String.format(" with impossible(%d)", s);
            return this;
        }

        private boolean exit(int y, int x, int s) {
            return x == 0 && y == 0 || x >= w - s && y >= h - s;
        }

        public Maze life() {
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    maze[i][j] = random.nextBoolean();
                }
            }
            for (int i = 0; i < 100; i++) {
                lifeStep();
            }
            do {
                lifeStep();
                printMaze(-1, -1, maze);
            } while (!isSolvable(maze));
            description = String.format("life %dx%d", h, w);
            return this;
        }

        private void lifeStep() {
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    int s = 0;
                    for (int dx = -1; dx <= 1; dx++) {
                        for (int dy = -1; dy <= 1; dy++) {
                            s += blocked(i + dy, j + dx) ? 1 : 0;
                        }
                    }
                    if (maze[i][j]) {
                        maze[i][j] = !(s == 3);
                    } else {
                        maze[i][j] =  !(3 <= s && s <= 5);
                    }
                }
            }
            maze[0][0] = true;
            maze[h - 1][w - 1] = true;
        }

        public Maze empty() {
            fill(true);
            description = String.format("empty %dx%d", h, w);
            return this;
        }

        public Maze noise(double p) {
            if (p == 0) {
                return this;
            }
            Maze m;
            do {
                m = copy();
                for (int i = 1; i < h - 1; i++) {
                    for (int j = 1; j < w - 1; j++) {
                        m.maze[i][j] = maze[i][j] ^ (p > random.nextDouble());
                    }
                }
            } while (!isSolvable(m.maze));
            m.description = description + String.format(", noise(%f)", p);
            return m;
        }

        private Maze copy() {
            Maze m = new Maze(h, w);
            for (int i = 0; i < h; i++) {
                for (int j = 0; j < w; j++) {
                    m.maze[i][j] = maze[i][j];
                }
            }
            return m;
        }

        int encode(int ny, int nx) {
            return ny * w + nx;
        }

        boolean addNew(int c, int s, IntList intList) {
            int y = c / w;
            int x = c % w;
            if (h < y + s || w < x + s) {
                return false;
            }

            boolean ok = blocked(y - 1, x - 1, y + 1, x + s + 1) || blocked(y + s - 1, x - 1, y + s + 1, x + s + 1) ||
                    blocked(y - 1, x - 1, y + s + 1, x + 1) || blocked(y - 1, x + s - 1, y + s + 1, x + s + 1);
            if (ok || exit(y, x, s)) {
                intList.v[y][x] = true;
                intList.found |= x == w - s && y == h - s;
                fill(y, x, y + 1, x + s, true);
                fill(y + s - 1, x, y + s, x + s, true);
                fill(y, x, y + s, x + 1, true);
                fill(y, x + s - 1, y + s, x + s, true);
//                printMaze(y, x, maze);
                addNeighbors(y, x, intList);
                return true;
            }
            return false;
        }

        private void fill(int y1, int x1, int y2, int x2, boolean b) {
            for (int i = y1; i < y2; i++) {
                for (int j = x1; j < x2; j++) {
                    maze[i][j] = b;
                }
            }
        }

        boolean blocked(int y1, int x1, int y2, int x2) {
            for (int i = y1; i < y2; i++) {
                for (int j = x1; j < x2; j++) {
                    if (!blocked(i, j)) {
                        return false;
                    }
                }
            }
            return true;
        }

        void addNeighbors(int y, int x, IntList intList) {
            for (int i : shuffled[random.nextInt(shuffled.length)]) {
                add(y, x, y + DY[i], x + DX[i], intList);
            }
        }

        void add(int y, int x, int ny, int nx, IntList intList) {
            if (inside(ny, nx) && (!u[ny][nx] || exit(ny, nx, 1))) {
                u[ny][nx] = true;
                intList.add(encode(ny, nx));
            }
        }

        public Maze minimizeSolutions() {
            Solution base = solve();
            if (base.solutions.size <= 1 || base.s == 1 || random.nextBoolean()) {
                return this;
            }

            int target = base.s - random.nextInt(base.s / 2 + 1);
            System.out.format("    minimising solution from %d to %d\n", base.solutions.size, target);
            int[] tweaks = createTweaks();
            int l = 0;
            int r = 1;
            while (true) {
                int m = Math.min(tweaks.length, r * 2);
                Maze z = copy();
                for (int i = 0; i < m; i++) {
                    z.maze[tweaks[i] / w][tweaks[i] % w] = false;
                }
                l = r;
                r = m;
                if (!isSolvable(z.maze)) {
                    break;
                }
                Solution s = z.solve();
                if (s.solutions.isEmpty() || s.s < target) {
                    break;
                }
                System.out.println("    minimizing solutions from " + base.solutions.size + " d = " + (r - l));
            }
            while (l < r) {
                System.out.println("    minimizing solutions from " + base.solutions.size + " d = " + (r - l));
                int m = (l + r) / 2;
                Maze z = copy();
                for (int i = 0; i < m; i++) {
                    z.maze[tweaks[i] / w][tweaks[i] % w] = false;
                }
                if (!isSolvable(z.maze)) {
                    r = m;
                    continue;
                }
                Solution s = z.solve();
                if (s.solutions.isEmpty() || s.s <= target) {
                    r = m;
                } else {
                    l = m + 1;
                }
            }
            Maze z = copy();
            for (int i = 0; i < l - 1; i++) {
                z.maze[tweaks[i] / w][tweaks[i] % w] = false;
            }
            z.description = description + " solutions minimized";
            return z;
        }

        private int[] createTweaks() {
            int[] tweaks = new int[(w - 2) * (h - 2)];
            int c = 0;
            for (int i = 1; i < h - 1; i++) {
                for (int j = 1; j < w - 1; j++) {
                    tweaks[c++] = i * w + j;
                }
            }
            assert c == tweaks.length;
            shuffle(tweaks);
            return tweaks;
        }

        void shuffle(int[] blueprint) {
            for (int i = 0; i < blueprint.length; i++) {
                int j = random.nextInt(i + 1);
                int t = blueprint[i];
                blueprint[i] = blueprint[j];
                blueprint[j] = t;
            }
        }

        public Maze addHoles() {
            Solution base = solve();
            if (base.solutions.isEmpty() || w * h > 100000) {
                return this;
            }

            int target = base.s - random.nextInt(base.s / 5 + 1);

            int holes = 0;
            int[] tweaks = createTweaks();
            Maze z = copy();
            int i = 0;
            int j = 0;
            for (int tweak : tweaks) {
                if (++i % 1000 == 0) {
                    System.out.format("    adding holes, %d of %d (%d of %d accepted)\n", i, tweaks.length, holes, j);
                }
                if (!maze[tweak / w][tweak % w] && 0.5 > random.nextDouble()) {
                    z.maze[tweak / w][tweak % w] = true;
                    holes++;
                    j++;
                    Solution s = z.solve();
                    if (s.solutions.isEmpty() || s.s < target) {
                        z.maze[tweak / w][tweak % w] = false;
                        holes--;
                    }
                }
            }
            z.description = String.format("%s, %d holes added", description, holes);
            return z;
        }

        public Maze addBarriers() {
            Solution base = solve();
            if (base.solutions.isEmpty() || w * h > 100000) {
                return this;
            }

            int target = base.s - random.nextInt(base.s / 5 + 1);

            int barriers = 0;
            int[] tweaks = createTweaks();
            Maze z = copy();
            int i = 0;
            int j= 0;
            for (int tweak : tweaks) {
                if (++i % 1000 == 0) {
                    System.out.format("    adding barriers, %d of %d (%d of %d accepted)\n", i, tweaks.length, barriers, j);
                }
                if (maze[tweak / w][tweak % w] && 0.5 > random.nextDouble()) {
                    z.maze[tweak / w][tweak % w] = false;
                    barriers++;
                    j++;
                    Solution s = z.solve();
                    if (s.solutions.isEmpty() || s.s < target) {
                        z.maze[tweak / w][tweak % w] = true;
                        barriers--;
                    }
                }
            }
            z.description = String.format("%s, %d barriers added", description, barriers);
            return z;
        }

        class Cells {
            int[][] sums = new int[h + 1][w + 1];

            public Cells(boolean[][] maze, boolean empty) {
                for (int i = 1; i <= maze.length; i++) {
                    int sum = 0;
                    for (int j = 1; j <= maze[i - 1].length; j++) {
                        sum += (maze[i - 1][j - 1] == empty ? 0 : 1);
                        sums[i][j] = sum + (i > 0 ? sums[i - 1][j] : 0);
                    }
                }
            }

            public boolean exist(int s, int i, int j) {
                j -= s - 1;
                return sums[i + s][j + s] - sums[i][j + s] - sums[i + s][j] + sums[i][j] > 0;
            }
        }

        Solution solve() {
            Solution solution = new Solution(h, w);
            solution.s = Integer.MAX_VALUE;
            if (!isSolvable(maze)) {
                return solution;
            }

            Cells path1 = new Cells(findWay(0, 1), false);
            Cells path2 = new Cells(findWay(1, -1), false);

            maze[0][0] = false;
            maze[h - 1][w - 1] = false;
            Cells walls = new Cells(maze, true);

            maze[0][0] = true;
            maze[h - 1][w - 1] = true;

            for (int i = 0; i < h; i++) {
                int s = 0;
                for (int j = 0; j < w; j++) {
                    s++;
                    while (h < i + s || walls.exist(s, i, j)) s--;
                    if (path1.exist(s, i, j) && path2.exist(s, i, j)) {
                        while (s > 0 && path1.exist(s - 1, i, j) && path2.exist(s - 1, i, j)) s--;
                        if (solution.s > s) {
                            solution.s = s;
                            solution.solutions.clear();
                        }
                        if (solution.s == s) {
                            solution.solutions.add(i * w + (j - s + 1));
                        }
                    }
                }
            }
            return solution;
        }

        boolean[][] findWay(int d, int dd) {
            boolean[][] way = new boolean[h][w];
            int x = 0;
            int y = 0;
            while (x != w - 1 || y != h - 1) {
                way[y][x] = true;
                d = (d - dd + 4) % 4;
                for (int i = 0; i < 3; i++) {
                    int nx = x + DX[d];
                    int ny = y + DY[d];
                    if (0 <= nx && nx < w && 0 <= ny && ny < h && maze[ny][nx]) {
                        x = nx;
                        y = ny;
                        break;
                    }
                    d = (d + dd + 4) % 4;
                }
            }
            return way;
        }
    }

    class Solution {
        int s;
        IntList solutions;

        public Solution(int h, int w) {
            solutions = new IntList(h, w);
        }
    }

    int randomScale(int scale) {
        return scale - random.nextInt(scale / 5 + 1);
    }

    public void run() throws IOException {
        manual();
        int[] sizes = {15, 100, MAX_N};
        int[] scales = {1, 5, 20, 200, MAX_N / 5};
        for (int h : sizes) {
            for (int w : sizes) {
                if (h < w) {
                    continue;
                }
                new Maze(h, w).empty().write();
                new Maze(h, randomScale(h)).empty().write();
                new Maze(randomScale(h) - 1, w).empty().write();
                new Maze(h, w).empty().noise(0.00001).write();
                for (int s : scales) {
                    if (h <= s || w <= s) {
                        continue;
                    }
                    double noise = s > 1 ? 0.001 : 0;
                    maze(h / s, w / s).dfs(1).scale(randomScale(s), 0).write();
                    maze(h, w).dfs(randomScale(s)).minimizeSolutions().write();
                    maze(h / s, w / s).prim(1).scale(randomScale(s), 0).write();
                    maze(h, w).prim(randomScale(s)).minimizeSolutions().write();
                    maze(h / s, w / s).dfs(1).or(maze(h / s * 2, h / s * 2).prim(1)).scale(s, 0).write();
                    maze(h / s * s, w / s * s).dfs(randomScale(s)).or(maze(h / s * 2, h / s * 2).prim(1).scale(s, 0)).minimizeSolutions().write();
                    maze(h, w).dfs(randomScale(s)).or(maze(h * 2, h * 2).prim(randomScale(s))).minimizeSolutions().write();
////////                    new Maze(h / s, w / s).life().scale(s, noise).write();
                    if (h / w <= 25) {
                        maze(h, w).recursive(randomScale(s) + 1, true).minimizeSolutions().write();
                        maze(h, w).recursive(randomScale(s) + 1, false).minimizeSolutions().write();
                        maze(h / s, w / s).primPaths(1, true).scale(s, noise).write();
                        maze(h / s, w / s).primPaths(1, false).scale(s, noise).minimizeSolutions().write();
                        maze(h, w).primPaths(randomScale(s), true).write();
                        maze(h, w).primPaths(randomScale(s), false).minimizeSolutions().write();
                    }
                    if (h * w / s / s <= 30000) {
                        maze(h / s, w / s).dfs(1).addHoles().scale(s, noise).minimizeSolutions().write();
                        maze(h / s, w / s).prim(1).addHoles().scale(s, noise).minimizeSolutions().write();
                        maze(h / s, w / s).dfs(1).addBarriers().scale(s, noise).minimizeSolutions().write();
                        maze(h / s, w / s).prim(1).addBarriers().scale(s, noise).minimizeSolutions().write();
                    }
                    if (s != 1 && h * w <= 30000) {
                        new Maze(h, w).dfs(randomScale(s)).addHoles().minimizeSolutions().write();
                        new Maze(w, h).prim(randomScale(s)).addHoles().minimizeSolutions().write();
                        new Maze(h, w).dfs(randomScale(s)).addBarriers().minimizeSolutions().write();
                        new Maze(w, h).prim(randomScale(s)).addBarriers().minimizeSolutions().write();
                    }
                }
            }
        }
    }

    private Tests.Maze maze(int h, int w) {
        h -= random.nextInt(h / 5 + 1);
        w -= random.nextInt(w / 5 + 1);
        return random.nextBoolean() ? new Tests.Maze(h, w) : new Tests.Maze(w, h);
    }

    public static void main(String[] args) throws IOException {
        new File("tests").mkdir();
        new File("images").mkdir();
        descriptions = new PrintWriter("tests/tests.lst");
        new Tests().run();
        descriptions.close();
    }
}

