/******************************************************************/
/* ACM ICPC 2012-2013                                             */
/* Northeastern European Regional Contest                         */
/* St Petersburg - Barnaul - Tashkent - Tbilisi, December 2, 2012 */
/******************************************************************/
/* Problem L. Labyrinth of the Minotaur                           */
/*                                                                */
/* Original idea         Georgiy Korneev                          */
/* Problem statement     Georgiy Korneev                          */
/* Test set              Georgiy Korneev                          */
/******************************************************************/
/* Solution                                                       */
/*                                                                */
/* Author                Petr Mitrichev                           */
/******************************************************************/

import java.io.IOException;
import java.io.OutputStreamWriter;
import java.io.BufferedWriter;
import java.util.InputMismatchException;
import java.io.FileOutputStream;
import java.io.OutputStream;
import java.io.PrintWriter;
import java.io.FileInputStream;
import java.io.Writer;
import java.math.BigInteger;
import java.io.InputStream;

/**
 * Built using CHelper plug-in
 * Actual solution is at the top
 */
public class labyrinth_petr {
	public static void main(String[] args) {
		InputStream inputStream;
		try {
			inputStream = new FileInputStream("labyrinth.in");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		OutputStream outputStream;
		try {
			outputStream = new FileOutputStream("labyrinth.out");
		} catch (IOException e) {
			throw new RuntimeException(e);
		}
		InputReader in = new InputReader(inputStream);
		OutputWriter out = new OutputWriter(outputStream);
		Labyrinth solver = new Labyrinth();
		solver.solve(1, in, out);
		out.close();
	}
}

class Labyrinth {
    static final int[] dr = new int[]{1, 0, -1, 0};
    static final int[] dc = new int[]{0, -1, 0, 1};

    int w;
    int h;
    String[] field;
    int[][] color;

    public void solve(int testNumber, InputReader in, OutputWriter out) {
        w = in.readInt();
        h = in.readInt();
        field = new String[h];
        for (int r = 0; r < h; ++r) field[r] = in.next();
        color = new int[h][w];
        color[0][0] |= 4;
        color[h - 1][w - 1] |= 4;
        paint(1);
        for (int i = 0; i < 2; ++i) {
            int tmp = dr[i];
            dr[i] = dr[3 - i];
            dr[3 - i] = tmp;
            tmp = dc[i];
            dc[i] = dc[3 - i];
            dc[3 - i] = tmp;
        }
        paint(2);
        int[][] sums = new int[h + 1][w + 1];
        int[][] color1 = new int[h + 1][w + 1];
        int[][] color2 = new int[h + 1][w + 1];
        for (int r = 0; r < h; ++r)
            for (int c = 0; c < w; ++c) {
                sums[r + 1][c + 1] = sums[r + 1][c] + sums[r][c + 1] - sums[r][c] + (field[r].charAt(c) == '#' ? 1 : 0);
                color1[r + 1][c + 1] = color1[r + 1][c] + color1[r][c + 1] - color1[r][c] + ((color[r][c] & 1) == 0 ? 0 : 1);
                color2[r + 1][c + 1] = color2[r + 1][c] + color2[r][c + 1] - color2[r][c] + ((color[r][c] & 2) == 0 ? 0 : 1);
                if (r == 0 && c == 0) ++sums[r + 1][c + 1];
                if (r == h - 1 && c == w - 1) ++sums[r + 1][c + 1];
            }
        int res = Math.max(h, w) + 1;
        int rr = -1;
        int rc = -1;
        for (int sr = 0; sr < h; ++sr)
            for (int sc = 0; sc < w; ++sc) {
                int left = 0;
                int right = Math.min(h - sr, w - sc) + 1;
                while (right - left > 1) {
                    int middle = (left + right) / 2;
                    int er = sr + middle;
                    int ec = sc + middle;
                    if (sums[er][ec] + sums[sr][sc] - sums[er][sc] - sums[sr][ec] != 0)
                        right = middle;
                    else if ((color1[er][ec] + color1[sr][sc] - color1[er][sc] - color1[sr][ec] > 0) && (color2[er][ec] + color2[sr][sc] - color2[er][sc] - color2[sr][ec] > 0))
                        right = middle;
                    else
                        left = middle;
                }
                {
                    int er = sr + right;
                    int ec = sc + right;
                    if (er > h || ec > w || sums[er][ec] + sums[sr][sc] - sums[er][sc] - sums[sr][ec] != 0) {
                        // Bad.
                    } else {
                        if (right < res) {
                            res = right;
                            rr = sr;
                            rc = sc;
                        }
                    }
                }
            }
        /*for (int er = 1; er <= h; ++er)
            for (int ec = 1; ec <= w; ++ec) {
                int left = 0;
                int right = Math.min(er, ec) + 1;
                while (right - left > 1) {
                    int middle = (left + right) / 2;
                    int sr = er - middle;
                    int sc = ec - middle;
                    if (sums[er][ec] + sums[sr][sc] - sums[er][sc] - sums[sr][ec] != 0)
                        right = middle;
                    else if ((color1[er][ec] + color1[sr][sc] - color1[er][sc] - color1[sr][ec] > 0) && (color2[er][ec] + color2[sr][sc] - color2[er][sc] - color2[sr][ec] > 0))
                        right = middle;
                    else
                        left = middle;
                }
                {
                    int sr = er - right;
                    int sc = ec - right;
                    if (sr < 0 || sc < 0 || sums[er][ec] + sums[sr][sc] - sums[er][sc] - sums[sr][ec] != 0) {
                        // Bad.
                    } else {
                        if (right < res) {
                            res = right;
                            rr = sr;
                            rc = sc;
                        }
                    }
                }
            }*/
        if (rr < 0) {
            out.printLine("Impossible");
        } else {
            out.printLine(res + " " + (rc + 1) + " " + (rr + 1));
        }
    }

    private void paint(int col) {
        int r = 0;
        int c = 0;
        int d = 0;
        color[r][c] |= col;
        while (r < h - 1 || c < w - 1) {
            int nr = r + dr[d];
            int nc = c + dc[d];
            if (nr >= 0 && nr < h && nc >= 0 && nc < w && field[nr].charAt(nc) == '.') {
                r = nr;
                c = nc;
                color[r][c] |= col;
                d = (d + 1) % 4;
            } else {
                d = (d + 3) % 4;
            }
        }
    }
}

class InputReader {

	private InputStream stream;
	private byte[] buf = new byte[1024];
	private int curChar;
	private int numChars;
	private SpaceCharFilter filter;

	public InputReader(InputStream stream) {
		this.stream = stream;
	}

	public int read() {
		if (numChars == -1)
			throw new InputMismatchException();
		if (curChar >= numChars) {
			curChar = 0;
			try {
				numChars = stream.read(buf);
			} catch (IOException e) {
				throw new InputMismatchException();
			}
			if (numChars <= 0)
				return -1;
		}
		return buf[curChar++];
	}

	public int readInt() {
		int c = read();
		while (isSpaceChar(c))
			c = read();
		int sgn = 1;
		if (c == '-') {
			sgn = -1;
			c = read();
		}
		int res = 0;
		do {
			if (c < '0' || c > '9')
				throw new InputMismatchException();
			res *= 10;
			res += c - '0';
			c = read();
		} while (!isSpaceChar(c));
		return res * sgn;
	}

	public String readString() {
		int c = read();
		while (isSpaceChar(c))
			c = read();
		StringBuilder res = new StringBuilder();
		do {
			res.appendCodePoint(c);
			c = read();
		} while (!isSpaceChar(c));
		return res.toString();
	}

	public boolean isSpaceChar(int c) {
		if (filter != null)
			return filter.isSpaceChar(c);
		return c == ' ' || c == '\n' || c == '\r' || c == '\t' || c == -1;
	}

	public String next() {
		return readString();
	}

	public interface SpaceCharFilter {
		public boolean isSpaceChar(int ch);
	}
}

class OutputWriter {
	private final PrintWriter writer;

	public OutputWriter(OutputStream outputStream) {
		writer = new PrintWriter(new BufferedWriter(new OutputStreamWriter(outputStream)));
	}

	public OutputWriter(Writer writer) {
		this.writer = new PrintWriter(writer);
	}

	public void print(Object...objects) {
		for (int i = 0; i < objects.length; i++) {
			if (i != 0)
				writer.print(' ');
			writer.print(objects[i]);
		}
	}

	public void printLine(Object...objects) {
		print(objects);
		writer.println();
	}

	public void close() {
		writer.close();
	}

	}


